
from formant.sdk.cloud.v2.formant_admin_api_client.models import DeviceOfflineEventStreamType, TeleopRequestData, TeleopSessionRecordStreamType, PortForwardingSessionRecordStreamType, EventSeekQueryEventTypesItem, EventFilter, Annotation, CustomEventSeverity, InterventionRequestStreamType, DeviceOnlineEventSeverity, InterventionRequestInterventionType, CommentType, TeleopSessionRecord, AnnotationType, TaskSummaryTags, EventQuery, EventSeekQueryDirection, SelectionRequestData, TaskSummaryStreamType, EventSortOrder, DatapointEventStreamType, EventTriggerCommand, DeviceOfflineEventMetadata, AnnotationStreamType, CustomEvent, CustomEventMetadata, StatefulEventSeverity, PortForwardingSessionRecordTags, EventSeekQuery, EventQuerySeveritiesItem, CustomEventTags, StatefulEventMetadata, CustomEventType, InterventionRequestType, CommentTags, DatapointEvent, DeviceOnlineEventStreamType, AnnotationMetadata, DeviceOnlineEvent, CustomEventStreamType, EventSortColumn, TaskSummaryType, InterventionRequestSeverity, EventExportSheetRequest, DeviceOfflineEventTags, DeviceOnlineEventMetadata, DeviceOnlineEventTags, EventExportSheetResult, SystemEventTags, StatefulEvent, DatapointEventSeverity, PortForwardingSessionRecord, SystemEventMetadata, InterventionRequestTags, CommentStreamType, DeviceOfflineEventSeverity, DatapointEventType, TeleopSessionRecordType, SystemEvent, DatapointEventMetadata, EventSeekQuerySeveritiesItem, DeviceOfflineEvent, EventHistogram, SystemEventStreamType, CommandDeliveryEventTags, Comment, StatefulEventStreamType, EventListResponse, StatefulEventType, CommentMetadata, InterventionRequestMetadata, EventHistogramEntry, EventFilterEventTypesItem, TeleopSessionRecordTags, StatefulEventTags, EventQueryTypesItem, EventQueryEventTypesItem, CommandDeliveryEventStreamType, PortForwardingSessionRecordMetadata, Label, CommandDeliveryEventMetadata, DeviceOfflineEventType, PhysicalRequestData, SystemEventType, InterventionRequest, EventCounts, EventFilterTypesItem, DatapointEventTags, EventFilterSeveritiesItem, AnnotationTags, CommandDeliveryEvent, DeviceOnlineEventType, EventSort, TaskSummaryMetadata, LabelingRequestData, CommandDeliveryEventType, LabeledPolygon, TaskSummary, PortForwardingSessionRecordType, TeleopSessionRecordMetadata, EventSeekQueryTypesItem
from formant.sdk.cloud.v2.formant_admin_api_client.api.event import event_controller_query
from formant.sdk.cloud.v2.formant_admin_api_client.types import *



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.aggregate_row import AggregateRow
    from ..models.sql_column import SqlColumn


T = TypeVar("T", bound="StreamRowsResponse")


@attr.s(auto_attribs=True)
class StreamRowsResponse:
    """
    Attributes:
        items (List[Any]):
        sql_text (str):
        rows (List[Any]):
        columns (List['SqlColumn']):
        row_count (float):
        aggregates (Union[Unset, List['AggregateRow']]):
        aggregate_sql_text (Union[Unset, str]):
        unit (Union[Unset, str]):
    """

    items: List[Any]
    sql_text: str
    rows: List[Any]
    columns: List["SqlColumn"]
    row_count: float
    aggregates: Union[Unset, List["AggregateRow"]] = UNSET
    aggregate_sql_text: Union[Unset, str] = UNSET
    unit: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        items = self.items

        sql_text = self.sql_text
        rows = self.rows

        columns = []
        for columns_item_data in self.columns:
            columns_item = columns_item_data.to_dict()

            columns.append(columns_item)

        row_count = self.row_count
        aggregates: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.aggregates, Unset):
            aggregates = []
            for aggregates_item_data in self.aggregates:
                aggregates_item = aggregates_item_data.to_dict()

                aggregates.append(aggregates_item)

        aggregate_sql_text = self.aggregate_sql_text
        unit = self.unit

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "items": items,
                "sqlText": sql_text,
                "rows": rows,
                "columns": columns,
                "rowCount": row_count,
            }
        )
        if aggregates is not UNSET:
            field_dict["aggregates"] = aggregates
        if aggregate_sql_text is not UNSET:
            field_dict["aggregateSqlText"] = aggregate_sql_text
        if unit is not UNSET:
            field_dict["unit"] = unit

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.aggregate_row import AggregateRow
        from ..models.sql_column import SqlColumn

        d = src_dict.copy()
        items = cast(List[Any], d.pop("items"))

        sql_text = d.pop("sqlText")

        rows = cast(List[Any], d.pop("rows"))

        columns = []
        _columns = d.pop("columns")
        for columns_item_data in _columns:
            columns_item = SqlColumn.from_dict(columns_item_data)

            columns.append(columns_item)

        row_count = d.pop("rowCount")

        aggregates = []
        _aggregates = d.pop("aggregates", UNSET)
        for aggregates_item_data in _aggregates or []:
            aggregates_item = AggregateRow.from_dict(aggregates_item_data)

            aggregates.append(aggregates_item)

        aggregate_sql_text = d.pop("aggregateSqlText", UNSET)

        unit = d.pop("unit", UNSET)

        stream_rows_response = cls(
            items=items,
            sql_text=sql_text,
            rows=rows,
            columns=columns,
            row_count=row_count,
            aggregates=aggregates,
            aggregate_sql_text=aggregate_sql_text,
            unit=unit,
        )

        stream_rows_response.additional_properties = d
        return stream_rows_response

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties




from formant.sdk.cloud.v2.formant_admin_api_client.models import AnnotationField, Annotation, ScopeFilter, TagParameters, AnnotationMetadata, UserParameters, AnnotationFieldValue, AnnotationFieldType, AnnotationTemplate, AnnotationTemplateTags, ScopeFilterTypesItem, AnnotationFieldValuesRequest, UserParametersRolesItem, AnnotationType, AnnotationFieldValueTags, AnnotationTemplateListResponse, AnnotationTags, SheetParameters, AnnotationFieldValuesResponse, AnnotationStreamType, AnnotationFieldValuesRequestTags
from formant.sdk.cloud.v2.formant_admin_api_client.api.annotation import annotation_controller_post
from formant.sdk.cloud.v2.formant_admin_api_client.api.annotation_template import annotation_template_controller_list, annotation_template_controller_get_one
from formant.sdk.cloud.v2.formant_admin_api_client.types import *



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.aggregate_row_type import AggregateRowType
from ..types import UNSET, Unset

T = TypeVar("T", bound="AggregateRow")


@attr.s(auto_attribs=True)
class AggregateRow:
    """
    Attributes:
        name (str):
        stream_name (str):
        value (float):
        type (AggregateRowType):
        unit (Union[Unset, str]):
        label (Union[Unset, str]):
    """

    name: str
    stream_name: str
    value: float
    type: AggregateRowType
    unit: Union[Unset, str] = UNSET
    label: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        stream_name = self.stream_name
        value = self.value
        type = self.type.value

        unit = self.unit
        label = self.label

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "name": name,
                "streamName": stream_name,
                "value": value,
                "type": type,
            }
        )
        if unit is not UNSET:
            field_dict["unit"] = unit
        if label is not UNSET:
            field_dict["label"] = label

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        name = d.pop("name")

        stream_name = d.pop("streamName")

        value = d.pop("value")

        type = AggregateRowType(d.pop("type"))

        unit = d.pop("unit", UNSET)

        label = d.pop("label", UNSET)

        aggregate_row = cls(
            name=name,
            stream_name=stream_name,
            value=value,
            type=type,
            unit=unit,
            label=label,
        )

        aggregate_row.additional_properties = d
        return aggregate_row

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="SheetParameters")


@attr.s(auto_attribs=True)
class SheetParameters:
    """
    Attributes:
        spreadsheet_id (str):
        range_ (str):
        url (Union[Unset, str]):
    """

    spreadsheet_id: str
    range_: str
    url: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        spreadsheet_id = self.spreadsheet_id
        range_ = self.range_
        url = self.url

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "spreadsheetId": spreadsheet_id,
                "range": range_,
            }
        )
        if url is not UNSET:
            field_dict["url"] = url

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        spreadsheet_id = d.pop("spreadsheetId")

        range_ = d.pop("range")

        url = d.pop("url", UNSET)

        sheet_parameters = cls(
            spreadsheet_id=spreadsheet_id,
            range_=range_,
            url=url,
        )

        sheet_parameters.additional_properties = d
        return sheet_parameters

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar

import attr

if TYPE_CHECKING:
    from ..models.user import User


T = TypeVar("T", bound="CreateServiceAccountResponse")


@attr.s(auto_attribs=True)
class CreateServiceAccountResponse:
    """
    Attributes:
        user (User):
        password (str):
    """

    user: "User"
    password: str
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        user = self.user.to_dict()

        password = self.password

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "user": user,
                "password": password,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.user import User

        d = src_dict.copy()
        user = User.from_dict(d.pop("user"))

        password = d.pop("password")

        create_service_account_response = cls(
            user=user,
            password=password,
        )

        create_service_account_response.additional_properties = d
        return create_service_account_response

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties




from formant.sdk.cloud.v2.formant_query_api_client.models import StreamData, Quaternion, Transform, StreamDataType, NumericSetEntry, StreamDataPointsItem, Vector3, Path, PointCloud, Battery, Video, File, Video,VideoMimeType, StreamAggregateData, Health, Map, Bitset, Health,HealthStatus, Goal, TransformNode, VideoMimeType, QueryAggregate, ImageAnnotation, Image, StreamAggregateDataTags, Localization, StreamAggregateDataType, Query, Location, Twist, HealthStatus, QueryTypesItem, BoundingBox, StreamDataTags, Odometry, StreamDataListResponse
from formant.sdk.cloud.v2.formant_query_api_client.api.query import query_controller_query
from formant.sdk.cloud.v2.formant_query_api_client.types import *



from typing import Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="SelectionRequestData")


@attr.s(auto_attribs=True)
class SelectionRequestData:
    """
    Attributes:
        instruction (str):
        image_url (str):
        options (List[str]):
        hint (Union[Unset, int]):
        title (Union[Unset, str]):
    """

    instruction: str
    image_url: str
    options: List[str]
    hint: Union[Unset, int] = UNSET
    title: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        instruction = self.instruction
        image_url = self.image_url
        options = self.options

        hint = self.hint
        title = self.title

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "instruction": instruction,
                "imageUrl": image_url,
                "options": options,
            }
        )
        if hint is not UNSET:
            field_dict["hint"] = hint
        if title is not UNSET:
            field_dict["title"] = title

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        instruction = d.pop("instruction")

        image_url = d.pop("imageUrl")

        options = cast(List[str], d.pop("options"))

        hint = d.pop("hint", UNSET)

        title = d.pop("title", UNSET)

        selection_request_data = cls(
            instruction=instruction,
            image_url=image_url,
            options=options,
            hint=hint,
            title=title,
        )

        selection_request_data.additional_properties = d
        return selection_request_data

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar

import attr

T = TypeVar("T", bound="ChangePasswordRequest")


@attr.s(auto_attribs=True)
class ChangePasswordRequest:
    """
    Attributes:
        current_password (str):
        new_password (str):
        refresh_token (str):
    """

    current_password: str
    new_password: str
    refresh_token: str
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        current_password = self.current_password
        new_password = self.new_password
        refresh_token = self.refresh_token

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "currentPassword": current_password,
                "newPassword": new_password,
                "refreshToken": refresh_token,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        current_password = d.pop("currentPassword")

        new_password = d.pop("newPassword")

        refresh_token = d.pop("refreshToken")

        change_password_request = cls(
            current_password=current_password,
            new_password=new_password,
            refresh_token=refresh_token,
        )

        change_password_request.additional_properties = d
        return change_password_request

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, cast

import attr

T = TypeVar("T", bound="BeginUploadResponse")


@attr.s(auto_attribs=True)
class BeginUploadResponse:
    """
    Attributes:
        file_id (str):
        upload_id (str):
        part_urls (List[str]):
        part_size (int):
    """

    file_id: str
    upload_id: str
    part_urls: List[str]
    part_size: int
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        file_id = self.file_id
        upload_id = self.upload_id
        part_urls = self.part_urls

        part_size = self.part_size

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "fileId": file_id,
                "uploadId": upload_id,
                "partUrls": part_urls,
                "partSize": part_size,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        file_id = d.pop("fileId")

        upload_id = d.pop("uploadId")

        part_urls = cast(List[str], d.pop("partUrls"))

        part_size = d.pop("partSize")

        begin_upload_response = cls(
            file_id=file_id,
            upload_id=upload_id,
            part_urls=part_urls,
            part_size=part_size,
        )

        begin_upload_response.additional_properties = d
        return begin_upload_response

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.webhook_headers import WebhookHeaders


T = TypeVar("T", bound="Webhook")


@attr.s(auto_attribs=True)
class Webhook:
    """
    Attributes:
        name (Any):
        url (str):
        headers (Union[Unset, WebhookHeaders]):
    """

    name: Any
    url: str
    headers: Union[Unset, "WebhookHeaders"] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        url = self.url
        headers: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.headers, Unset):
            headers = self.headers.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "name": name,
                "url": url,
            }
        )
        if headers is not UNSET:
            field_dict["headers"] = headers

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.webhook_headers import WebhookHeaders

        d = src_dict.copy()
        name = d.pop("name")

        url = d.pop("url")

        _headers = d.pop("headers", UNSET)
        headers: Union[Unset, WebhookHeaders]
        if isinstance(_headers, Unset):
            headers = UNSET
        else:
            headers = WebhookHeaders.from_dict(_headers)

        webhook = cls(
            name=name,
            url=url,
            headers=headers,
        )

        webhook.additional_properties = d
        return webhook

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar

import attr

from ..models.user_teleop_twist_ros_topic_configuration_type import UserTeleopTwistRosTopicConfigurationType

if TYPE_CHECKING:
    from ..models.joystick_configuration import JoystickConfiguration


T = TypeVar("T", bound="UserTeleopTwistRosTopicConfiguration")


@attr.s(auto_attribs=True)
class UserTeleopTwistRosTopicConfiguration:
    """
    Attributes:
        type (UserTeleopTwistRosTopicConfigurationType):
        joystick (JoystickConfiguration):
    """

    type: UserTeleopTwistRosTopicConfigurationType
    joystick: "JoystickConfiguration"
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        type = self.type.value

        joystick = self.joystick.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "type": type,
                "joystick": joystick,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.joystick_configuration import JoystickConfiguration

        d = src_dict.copy()
        type = UserTeleopTwistRosTopicConfigurationType(d.pop("type"))

        joystick = JoystickConfiguration.from_dict(d.pop("joystick"))

        user_teleop_twist_ros_topic_configuration = cls(
            type=type,
            joystick=joystick,
        )

        user_teleop_twist_ros_topic_configuration.additional_properties = d
        return user_teleop_twist_ros_topic_configuration

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties




from formant.sdk.cloud.v2.formant_admin_api_client.models import ViewTags, NumericViewConfiguration, PartialView, View, ImageViewConfigurationMode, TransformTreeViewConfiguration, Camera, Vector3, ViewLayoutType, ViewConfigurationType, BitsetViewConfiguration, PartialViewLayoutType, LocationViewConfiguration, ImageViewConfiguration, Filter, LocationViewConfigurationBasemap, ViewListResponse, PartialViewTags, PointCloudViewConfiguration, Location, LocalizationViewConfiguration, ViewConfiguration, LocationViewport
from formant.sdk.cloud.v2.formant_admin_api_client.api.view import view_controller_get_one, view_controller_get_all, view_controller_patch
from formant.sdk.cloud.v2.formant_admin_api_client.types import *




from . import Response, UuidListResponse, online_devices_controller_online
from formant.sdk.cloud.v2.src.resources.resources import Resources

class OnlineDevices(Resources):

    def online(self):
        'See devices online currently'
        client = self._get_client()
        response: Response[UuidListResponse] = online_devices_controller_online.sync_detailed(client=client)
        return response

    async def online_async(self):
        'See devices online currently'
        client = self._get_client()
        response: Response[UuidListResponse] = (await online_devices_controller_online.asyncio_detailed(client=client))
        return response




from formant.sdk.cloud.v2.formant_admin_api_client.models import DeviceOfflineEventStreamType, OnDemandStreamPresence, DeviceStreamHardwareConfigurationHardwareType, ScopeFilter, DeviceStreamRosTransformTreeConfigurationType, DeviceFollower, TeleopJoystickConfigurationPosition, Network, ScopeFilterTypesItem, DeviceOnlineEventSeverity, DeviceStreamDirectoryWatchConfigurationType, DeviceStreamConfiguration, DeviceTeleopConfiguration, DeviceConfigurationTemplateListResponse, DeviceStreamCustomConfiguration, RtcInfoRtcIceTransportPoliciesItem, DeviceApplicationConfiguration, DeviceStreamHardwareConfigurationType, AudioDevice, DeviceReportedConfigurationState, DeviceStreamRosTopicConfiguration, DeviceTeleopHardwareStreamConfiguration, DeviceDetailsType, DeviceTeleopCustomStreamConfigurationQuality, DeviceState, DeviceOfflineEventMetadata, DeviceRosState, DeviceStreamConfigurationTags, DeviceStreamRosLocalizationConfiguration, DeviceTeleopCustomStreamConfigurationMode, DeviceStreamRosTransformTreeConfiguration, DeviceStreamHardwareConfigurationQuality, OnDemandPresenceStreamItemGroup, DeviceConfigurationTemplate, DeviceTeleopRosStreamConfigurationAudioCodec, OnDemandBufferBufferType, DeviceConfigurationDocument, DeviceDetailsTags, NodeInfo, DeviceRosConfiguration, DeviceType, DeviceConfigurationTemplateTags, DeviceOnlineEventStreamType, DeviceTeleopCustomStreamConfigurationRtcStreamType, DeviceTeleopRosStreamConfigurationNumericControlVisualization, DeviceTeleopCustomStreamConfiguration, DeviceQuery, DeviceOnlineEvent, DeviceScope, TeleopJoystickConfiguration, OnDemandPresenceStreamItemGroupDatapointType, PartialDevice, DevicePortForwardingConfiguration, DeviceStreamHardwareConfiguration, DeviceOfflineEventTags, DeviceConfiguration, RtcInfoRtcIceServerProtocol, DeviceOnlineEventMetadata, DeviceOnlineEventTags, OsInfo, DeviceProvisioning, DeviceStreamDirectoryWatchConfigurationFileType, ValidationConfiguration, DeviceTeleopRosStreamConfigurationMode, DeviceScopeTypesItem, OnvifDevice, OnDemandPresenceTimeRange, DeviceResourcesConfiguration, DeviceOfflineEventSeverity, DeviceStateEnv, DeviceTeleopHardwareStreamConfigurationHardwareType, DeviceStreamRosTopicConfigurationType, DeviceStreamConfigurationQuality, DeviceTeleopRosStreamConfigurationTopicType, DeviceDetailsListResponse, DeviceOfflineEvent, CommandProgress, VideoDevice, DeviceDiagnosticsConfiguration, DeviceStreamFileTailConfigurationFileFormat, DeviceTeleopRosStreamConfigurationQuality, DeviceTeleopHardwareStreamConfigurationRtcStreamType, DeviceProvisioningRequest, DeviceQueryType, NetworkInfo, RosTopic, DeviceStreamTransformConfiguration, DeviceStreamDirectoryWatchConfiguration, HwInfo, DeviceCredentials, DeviceTeleopHardwareStreamConfigurationMode, DeviceStreamFileTailConfiguration, DeviceListResponse, KernelInfo, AdapterConfiguration, TeleopJoystickAxisConfigurationDimension, DeviceApplicationConfigurationConfigurationMap, DeviceStreamFileTailConfigurationType, DeviceTeleopRosStreamConfiguration, TeleopViewConfiguration, Device, RtcInfo, DeviceOfflineEventType, DeviceTelemetryConfiguration, DeviceBlobData, DeviceStreamRosLocalizationConfigurationType, PartialDeviceTags, DeviceTeleopHardwareStreamConfigurationQuality, DeviceTags, DeviceDetails, OnDemandBuffer, DeviceStreamCustomConfigurationType, TeleopJoystickAxisConfiguration, DeviceOnlineEventType, DeviceDiskConfiguration, DeviceTeleopCustomStreamConfigurationNumericControlVisualization, PartialDeviceType, DeviceConfigurationDocumentTags, OnDemandState
from formant.sdk.cloud.v2.formant_admin_api_client.api.device import device_controller_query, device_controller_patch, device_controller_get_one, device_controller_get_configuration, device_controller_post_configuration
from formant.sdk.cloud.v2.formant_admin_api_client.types import *
from formant.sdk.cloud.v2.formant_admin_api_client.types import Optional




from formant.sdk.cloud.v2.formant_admin_api_client.models import CommandTemplate, CommandParameterMeta, CommandResponse, CommandDeliveryEventStreamType, CommandListResponse, CommandResponseStreamType, ScopeFilter, FileInfo, CommandResponseTags, CommandDeliveryEventMetadata, CommandProgress, ScopeFilterTypesItem, CommandStreamType, CommandDeliveryEventTags, CommandTags, CommandQuery, CommandTemplateListResponse, Command, CommandRequest, CommandTemplateParameterMeta, CommandDeliveryEvent, CommandParameter, CommandDeliveryEventType, CommandRequestListResponse, CommandTemplateTags
from formant.sdk.cloud.v2.formant_admin_api_client.api.command import command_controller_post, command_controller_query
from formant.sdk.cloud.v2.formant_admin_api_client.types import *
